@@ -29,15 +29,29 @@ export interface IWorkspacesDefaultPlugins {
 }
 
 export interface IServerConfig {
+  containerBuild: {
+    containerBuildConfiguration?: {
+      openShiftSecurityContextConstraint?: string;
+    };
+    disableContainerBuildCapabilities?: boolean;
+  };
   defaults: {
     editor: string | undefined;
     components: V220DevfileComponents[];
     plugins: IWorkspacesDefaultPlugins[];
     pvcStrategy: string | undefined;
   };
+  pluginRegistry: {
+    openVSXURL: string;
+  };
   timeouts: {
     inactivityTimeout: number;
     runTimeout: number;
   };
   cheNamespace: string;
 }
+
+export interface IUserProfile {
+  email: string;
+  username: string;
+}
