@@ -14,4 +14,9 @@ module.exports = {
   extends: [
     'stylelint-config-standard',
   ],
+  rules: {
+    'selector-class-pattern': null,
+    'custom-property-pattern': null,
+    'keyframes-name-pattern': null,
+  }
 }
