@@ -26,6 +26,7 @@ export interface AlertItem {
   children?: React.ReactNode;
   actionCallbacks?: ActionCallback[];
   error?: never;
+  timeout?: boolean | number;
 }
 
 export interface FactoryResolver {
@@ -85,7 +86,7 @@ export enum LoaderTab {
 export enum WorkspaceDetailsTab {
   OVERVIEW = 'Overview',
   DEVFILE = 'Devfile',
-  LOGS = 'Logs',
+  DEVWRKSPACE = 'DevWorkspace',
 }
 
 export enum WorkspaceAction {
