@@ -15,15 +15,15 @@ import common from '@eclipse-che/common';
 import { AppThunk } from '..';
 import { fetchRegistryMetadata, fetchDevfile } from '../../services/registry/devfiles';
 import { createObject } from '../helpers';
-import { container } from '../../inversify.config';
-import { CheWorkspaceClient } from '../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 import { selectPlugins } from '../Plugins/chePlugins/selectors';
 import { isDevworkspacesEnabled } from '../../services/helpers/devworkspace';
 import fetchAndUpdateDevfileSchema from './fetchAndUpdateDevfileSchema';
 import devfileApi from '../../services/devfileApi';
 import { fetchResources, loadResourcesContent } from '../../services/registry/resources';
+import updateDevWorkspacePlugins from './updateDevWorkspacePlugins';
+import { AUTHORIZED, SanityCheckAction } from '../sanityCheckMiddleware';
+import { getDevfileSchema } from '../../services/dashboard-backend-client/devWorkspaceApi';
 
-const WorkspaceClient = container.get(CheWorkspaceClient);
 export const DEFAULT_REGISTRY = '/dashboard/devfile-registry/';
 
 export type DevWorkspaceResources = [devfileApi.DevWorkspace, devfileApi.DevWorkspaceTemplate];
@@ -70,12 +70,11 @@ export enum Type {
   REQUEST_SCHEMA = 'REQUEST_SCHEMA',
   RECEIVE_SCHEMA = 'RECEIVE_SCHEMA',
   RECEIVE_SCHEMA_ERROR = 'RECEIVE_SCHEMA_ERROR',
-  UPDATE_PREBUILT_TEMPLATES = 'UPDATE_PREBUILT_TEMPLATES',
   SET_FILTER = 'SET_FILTER',
   CLEAR_FILTER = 'CLEAR_FILTER',
 }
 
-export interface RequestRegistryMetadataAction {
+export interface RequestRegistryMetadataAction extends Action, SanityCheckAction {
   type: Type.REQUEST_REGISTRY_METADATA;
 }
 
@@ -91,7 +90,7 @@ export interface ReceiveRegistryErrorAction {
   error: string;
 }
 
-export interface RequestDevfileAction {
+export interface RequestDevfileAction extends Action, SanityCheckAction {
   type: Type.REQUEST_DEVFILE;
 }
 
@@ -101,7 +100,7 @@ export interface ReceiveDevfileAction {
   devfile: string;
 }
 
-export interface RequestResourcesAction {
+export interface RequestResourcesAction extends Action, SanityCheckAction {
   type: Type.REQUEST_RESOURCES;
 }
 
@@ -118,7 +117,7 @@ export interface ReceiveResourcesErrorAction {
   error: string;
 }
 
-export interface RequestSchemaAction {
+export interface RequestSchemaAction extends Action, SanityCheckAction {
   type: Type.REQUEST_SCHEMA;
 }
 
@@ -173,7 +172,7 @@ export const actionCreators: ActionCreators = {
   requestRegistriesMetadata:
     (registryUrls: string): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch): Promise<void> => {
-      dispatch({ type: Type.REQUEST_REGISTRY_METADATA });
+      await dispatch({ type: Type.REQUEST_REGISTRY_METADATA, check: AUTHORIZED });
 
       const registries: string[] = registryUrls.split(' ');
       if (DEFAULT_REGISTRY) {
@@ -215,7 +214,7 @@ export const actionCreators: ActionCreators = {
   requestDevfile:
     (url: string): AppThunk<KnownAction, Promise<string>> =>
     async (dispatch): Promise<string> => {
-      dispatch({ type: Type.REQUEST_DEVFILE });
+      await dispatch({ type: Type.REQUEST_DEVFILE, check: AUTHORIZED });
       try {
         const devfile = await fetchDevfile(url);
         dispatch({ type: Type.RECEIVE_DEVFILE, devfile, url });
@@ -228,7 +227,7 @@ export const actionCreators: ActionCreators = {
   requestResources:
     (resourcesUrl: string): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch): Promise<void> => {
-      dispatch({ type: Type.REQUEST_RESOURCES });
+      await dispatch({ type: Type.REQUEST_RESOURCES, check: AUTHORIZED });
 
       try {
         const resourcesContent = await fetchResources(resourcesUrl);
@@ -240,6 +239,7 @@ export const actionCreators: ActionCreators = {
         if (!devWorkspace) {
           throw new Error('Failed to find a devworkspace in prebuilt resources.');
         }
+        updateDevWorkspacePlugins(devWorkspace);
         const devWorkspaceTemplate = resources.find(
           resource => resource.kind === 'DevWorkspaceTemplate',
         ) as devfileApi.DevWorkspaceTemplate;
@@ -268,12 +268,12 @@ export const actionCreators: ActionCreators = {
   requestJsonSchema:
     (): AppThunk<KnownAction, any> =>
     async (dispatch, getState): Promise<any> => {
-      dispatch({ type: Type.REQUEST_SCHEMA });
+      await dispatch({ type: Type.REQUEST_SCHEMA, check: AUTHORIZED });
       try {
         const state = getState();
-        const schemav1 = await WorkspaceClient.restApiClient.getDevfileSchema<{
+        const schemav1 = (await getDevfileSchema('1.0.0')) as {
           [key: string]: any;
-        }>('1.0.0');
+        };
         const items = selectPlugins(state);
         const components = schemav1?.properties?.components;
         if (components) {
@@ -323,12 +323,13 @@ export const actionCreators: ActionCreators = {
           );
           const parsedSchemaV1 = JSON.parse(patchedJSONString);
 
-          const schemav200 = await fetchAndUpdateDevfileSchema(WorkspaceClient, '2.0.0');
-          const schemav210 = await fetchAndUpdateDevfileSchema(WorkspaceClient, '2.1.0');
-          const schemav220 = await fetchAndUpdateDevfileSchema(WorkspaceClient, '2.2.0');
+          const schemav200 = await fetchAndUpdateDevfileSchema('2.0.0');
+          const schemav210 = await fetchAndUpdateDevfileSchema('2.1.0');
+          const schemav220 = await fetchAndUpdateDevfileSchema('2.2.0');
+          const schemav221alpha = await fetchAndUpdateDevfileSchema('2.2.1-alpha');
 
           schema = {
-            oneOf: [parsedSchemaV1, schemav200, schemav210, schemav220],
+            oneOf: [parsedSchemaV1, schemav200, schemav210, schemav220, schemav221alpha],
           };
         }
 
