@@ -72,6 +72,10 @@ export class FakeStoreBuilder {
       isLoading: false,
       plugins: [],
     } as PluginsState,
+    sanityCheck: {
+      authorized: Promise.resolve(true),
+      lastFetched: 0,
+    },
     workspaces: {
       isLoading: false,
       namespace: '',
@@ -219,9 +223,13 @@ export class FakeStoreBuilder {
   ): FakeStoreBuilder {
     if (options.resolver) {
       this.state.factoryResolver.resolver = Object.assign({}, options.resolver as ResolverState);
+    } else {
+      delete this.state.factoryResolver.resolver;
     }
     if (options.converted) {
       this.state.factoryResolver.converted = Object.assign({}, options.converted as ConvertedState);
+    } else {
+      delete this.state.factoryResolver.converted;
     }
     this.state.factoryResolver.isLoading = isLoading;
     return this;
@@ -378,4 +386,16 @@ export class FakeStoreBuilder {
     const mockStore = createMockStore(middlewares);
     return mockStore(this.state);
   }
+
+  public withSanityCheck(options: {
+    authorized?: Promise<boolean>;
+    error?: string;
+    lastFetched?: number;
+  }) {
+    this.state.sanityCheck = Object.assign({}, this.state.sanityCheck, options);
+    if (this.state.sanityCheck.lastFetched === undefined) {
+      this.state.sanityCheck.lastFetched = Date.now();
+    }
+    return this;
+  }
 }
